/*
 * Copyright 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.camera.core;

import static com.google.common.truth.Truth.assertThat;

import android.os.Build;

import androidx.camera.testing.fakes.FakeCameraIdFilter;
import androidx.test.filters.SmallTest;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.robolectric.RobolectricTestRunner;
import org.robolectric.annotation.Config;
import org.robolectric.annotation.internal.DoNotInstrument;

@SmallTest
@RunWith(RobolectricTestRunner.class)
@DoNotInstrument
@Config(minSdk = Build.VERSION_CODES.LOLLIPOP)
public class CameraIdFilterSetTest {
    private CameraIdFilterSet mCameraIdFilterSet = new CameraIdFilterSet();

    @Test
    public void canAddCameraIdFilter() {
        CameraIdFilter filter = new FakeCameraIdFilter();
        mCameraIdFilterSet.addCameraIdFilter(filter);
        assertThat(mCameraIdFilterSet.getCameraIdFilters()).containsExactly(filter);
    }

    @Test
    public void canAddCameraIdFilterSet() {
        CameraIdFilter filter1 = new FakeCameraIdFilter();
        CameraIdFilter filter2 = new FakeCameraIdFilter();
        CameraIdFilterSet newCameraIdFilterSet = new CameraIdFilterSet();
        newCameraIdFilterSet.addCameraIdFilter(filter1);
        newCameraIdFilterSet.addCameraIdFilter(filter2);
        mCameraIdFilterSet.addCameraIdFilter(newCameraIdFilterSet);
        assertThat(mCameraIdFilterSet.getCameraIdFilters()).contains(filter1);
        assertThat(mCameraIdFilterSet.getCameraIdFilters()).contains(filter2);
    }
}
